@@ -560,7 +560,7 @@ class ExecutionServer(BaseServer):
             function_name = job["function_name"]
             uuid = job["uuid"]
             del self.queued_jobs[uuid]
-            LOGGER.critical("Calling %s with args %s" % (function_name, kwargs))
+            LOGGER.debug("Calling %s with args %s" % (function_name, kwargs))
             self._callExposedFunction(
                 exposed_function["function"],
                 exposed_function["interval"], 
@@ -577,17 +577,19 @@ class ExecutionServer(BaseServer):
         function_name, 
         uuid=None, 
         reservation_fast_cache=None):
-        d = self.callExposedFunction(
-            func, 
-            kwargs, 
-            function_name, 
-            uuid=uuid,
-            reservation_fast_cache=reservation_fast_cache)
-        d.addCallback(self._jobCountCallback)
-        d.addErrback(self._jobCountErrback)
+        d = maybeDeferred(self._jobCountCallback)
         d.addCallback(self._setNextRequest, uuid, interval, function_name)
+        #d = self.callExposedFunction(
+        #    func, 
+        #    kwargs, 
+        #    function_name, 
+        #    uuid=uuid,
+        #    reservation_fast_cache=reservation_fast_cache)
+        #d.addCallback(self._jobCountCallback)
+        #d.addErrback(self._jobCountErrback)
+        #d.addCallback(self._setNextRequest, uuid, interval, function_name)
         
-    def _jobCountCallback(self, data):
+    def _jobCountCallback(self, data=None):
         self.job_count += 1
         
     def _jobCountErrback(self, error):
